@@ -33,6 +33,8 @@ class Generator(ABC):
         pass
 
     def feed(self, points:List, results:List, redo=False):
+        '''Feed a list of points to the generator
+        '''
         assert len(points)==len(results), 'points and results must have the same length'
         if redo:
             self.clear_history()
@@ -42,7 +44,6 @@ class Generator(ABC):
     def clear_history(self):
         self.searcher = self.get_searcher(self.search_space, self.metric, self.mode)
 
-
     def _to_metric_values(self, results:Union[List, Dict, float, int]):
 
         def extract_from_dict(data):
